@@ -12,6 +12,7 @@ PRAXIS_NS = 'http://www.praxis.com.mx/'
 
 
 class Orden(BaseModel):
+    id: int
     categoria: types.CategoriaOrdenPago
 
     op_ord_clave: types.ClaveOrdenanteOrdenPago = types.ClaveOrdenanteOrdenPago.AMU
@@ -122,14 +123,15 @@ class Orden(BaseModel):
         return mensaje
 
     @classmethod
-    def parse_xml(cls, orden_xml, category):
-        orden = orden_xml.find('ordenpago')
+    def parse_xml(cls, mensaje_xml):
+        orden_xml = mensaje_xml.find('ordenpago')
 
         orden_data = {
-            'categoria': category,
+            'id': orden_xml.attrib['Id'],
+            'categoria': mensaje_xml.attrib['categoria'],
         }
 
-        for element in orden.getchildren():
+        for element in orden_xml.getchildren():
             tag = to_snake_case(element.tag)
             if tag in cls.__fields__:
                 orden_data[tag] = element.text
